@@ -13,6 +13,7 @@ import (
 	"gopkg.in/yaml.v3"
 
 	"github.com/superfly/flyctl/flyctl"
+	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/filemu"
 	"github.com/superfly/flyctl/internal/update"
 )
@@ -49,6 +50,14 @@ type Cache interface {
 	// is set to has no effect.
 	SetLatestRelease(channel string, r *update.Release)
 
+	// SetCurrentVersionInvalid sets the current version of flyctl as invalid
+	// because of the given error.
+	SetCurrentVersionInvalid(err error)
+
+	// IsCurrentVersionInvalid returns an error message if the given version
+	// of flyctl is currently invalid. If not, it returns an empty string.
+	IsCurrentVersionInvalid() string
+
 	// Save writes the YAML-encoded representation of c to the named file path via
 	// os.WriteFile.
 	Save(path string) error
@@ -69,6 +78,7 @@ type cache struct {
 	channel       string
 	lastCheckedAt time.Time
 	latestRelease *update.Release
+	invalidVer    *invalidVer
 }
 
 func (c *cache) Channel() string {
@@ -136,10 +146,40 @@ func (c *cache) SetLatestRelease(channel string, r *update.Release) {
 	c.lastCheckedAt = time.Now()
 }
 
+type invalidVer struct {
+	Ver    string
+	Reason string
+}
+
+func (c *cache) SetCurrentVersionInvalid(err error) {
+	c.mu.Lock()
+	defer c.mu.Unlock()
+
+	c.dirty = true
+
+	c.invalidVer = &invalidVer{Ver: buildinfo.ParsedVersion().String(), Reason: err.Error()}
+}
+
+func (c *cache) IsCurrentVersionInvalid() string {
+	c.mu.RLock()
+	defer c.mu.RUnlock()
+
+	if c.invalidVer == nil {
+		return ""
+	}
+
+	if c.invalidVer.Ver != buildinfo.ParsedVersion().String() {
+		return ""
+	}
+
+	return c.invalidVer.Reason
+}
+
 type wrapper struct {
 	Channel       string          `yaml:"channel,omitempty"`
 	LastCheckedAt time.Time       `yaml:"last_checked_at,omitempty"`
 	LatestRelease *update.Release `yaml:"latest_release,omitempty"`
+	InvalidVer    *invalidVer
 }
 
 func lockPath() string {
@@ -158,6 +198,10 @@ func (c *cache) Save(path string) (err error) {
 		Channel:       c.channel,
 		LastCheckedAt: c.lastCheckedAt,
 		LatestRelease: c.latestRelease,
+		InvalidVer:    c.invalidVer,
+	}
+	if c.invalidVer != nil && c.IsCurrentVersionInvalid() == "" {
+		w.InvalidVer = nil
 	}
 
 	if err = yaml.NewEncoder(&b).Encode(w); err != nil {
@@ -208,6 +252,7 @@ func Load(path string) (c Cache, err error) {
 			channel:       w.Channel,
 			lastCheckedAt: w.LastCheckedAt,
 			latestRelease: w.LatestRelease,
+			invalidVer:    w.InvalidVer,
 		}
 	}
 
