@@ -330,7 +330,7 @@ func runCallback(ctx context.Context, appName string, srcInfo *scanner.SourceInf
 			cfg, err := appconfig.LoadConfig(srcInfo.MergeConfig.Name)
 			if err == nil {
 				// In theory, any part of the configuration could be merged here, but for now
-				// we will only copy over the processes, release command, and volume
+				// we will only copy over the processes, release command, volume, and swap size
 				if srcInfo.Processes == nil {
 					srcInfo.Processes = cfg.Processes
 				}
@@ -342,6 +342,10 @@ func runCallback(ctx context.Context, appName string, srcInfo *scanner.SourceInf
 				if len(srcInfo.Volumes) == 0 && len(cfg.Mounts) > 0 {
 					srcInfo.Volumes = []scanner.Volume{cfg.Mounts[0]}
 				}
+
+				if cfg.SwapSizeMB != nil {
+					srcInfo.SwapSizeMB = *cfg.SwapSizeMB
+				}
 			}
 		}
 
